@@ -15,10 +15,10 @@ use rand::Rng;
 use crate::channel::{bounded, Sender};
 use crate::core::checkpoint::Checkpoint;
 use crate::core::cluster::{MetadataStorageType, StdResponse};
+use crate::core::runtime::ManagerStatus;
 use crate::dag::metadata::DagMetadata;
 use crate::runtime::coordinator::checkpoint_manager::CheckpointManager;
 use crate::runtime::HeartbeatRequest;
-use crate::runtime::ManagerStatus;
 use crate::storage::metadata::{MetadataStorage, TMetadataStorage};
 use crate::utils::fs::read_binary;
 use crate::utils::http::server::{as_ok_json, page_not_found};
